==> spire-1.3.3.tar.gz: spire-1.3.3/cmd/spire-server/cli/agent/ban.go <==
package agent

import (
	"context"
	"errors"
	"flag"

	"github.com/mitchellh/cli"
	"github.com/spiffe/go-spiffe/v2/spiffeid"
	agentv1 "github.com/spiffe/spire-api-sdk/proto/spire/api/server/agent/v1"
	"github.com/spiffe/spire/cmd/spire-server/util"
	common_cli "github.com/spiffe/spire/pkg/common/cli"
	"github.com/spiffe/spire/pkg/server/api"
)

type banCommand struct {
	// SPIFFE ID of agent being banned
	spiffeID string
}

// NewBanCommand creates a new "ban" subcommand for "agent" command.
func NewBanCommand() cli.Command {
	return NewBanCommandWithEnv(common_cli.DefaultEnv)
}

// NewBanCommandWithEnv creates a new "ban" subcommand for "agent" command
// using the environment specified
func NewBanCommandWithEnv(env *common_cli.Env) cli.Command {
	return util.AdaptCommand(env, new(banCommand))
}

func (*banCommand) Name() string {
	return "agent ban"
}

func (*banCommand) Synopsis() string {
	return "Ban an attested agent given its SPIFFE ID"
}

// Run ban an agent given its SPIFFE ID
func (c *banCommand) Run(ctx context.Context, env *common_cli.Env, serverClient util.ServerClient) error {
	if c.spiffeID == "" {
		return errors.New("a SPIFFE ID is required")
	}

	id, err := spiffeid.FromString(c.spiffeID)
	if err != nil {
		return err
	}

	agentClient := serverClient.NewAgentClient()
	if _, err := agentClient.BanAgent(ctx, &agentv1.BanAgentRequest{
		Id: api.ProtoFromID(id),
	}); err != nil {
		return err
	}

	return env.Println("Agent banned successfully")
}

func (c *banCommand) AppendFlags(fs *flag.FlagSet) {
	fs.StringVar(&c.spiffeID, "spiffeID", "", "The SPIFFE ID of the agent to ban (agent identity)")
}

==> spire-1.8.7.tar.gz: spire-1.8.7/cmd/spire-server/cli/agent/ban.go <==
package agent

import (
	"context"
	"errors"
	"flag"

	"github.com/mitchellh/cli"
	"github.com/spiffe/go-spiffe/v2/spiffeid"
	agentv1 "github.com/spiffe/spire-api-sdk/proto/spire/api/server/agent/v1"
	"github.com/spiffe/spire/cmd/spire-server/util"
	commoncli "github.com/spiffe/spire/pkg/common/cli"
	"github.com/spiffe/spire/pkg/common/cliprinter"
	"github.com/spiffe/spire/pkg/server/api"
)

type banCommand struct {
	env *commoncli.Env
	// SPIFFE ID of agent being banned
	spiffeID string
	printer  cliprinter.Printer
}

// NewBanCommand creates a new "ban" subcommand for "agent" command.
func NewBanCommand() cli.Command {
	return NewBanCommandWithEnv(commoncli.DefaultEnv)
}

// NewBanCommandWithEnv creates a new "ban" subcommand for "agent" command
// using the environment specified
func NewBanCommandWithEnv(env *commoncli.Env) cli.Command {
	return util.AdaptCommand(env, &banCommand{env: env})
}

func (*banCommand) Name() string {
	return "agent ban"
}

func (*banCommand) Synopsis() string {
	return "Ban an attested agent given its SPIFFE ID"
}

// Run ban an agent given its SPIFFE ID
func (c *banCommand) Run(ctx context.Context, _ *commoncli.Env, serverClient util.ServerClient) error {
	if c.spiffeID == "" {
		return errors.New("a SPIFFE ID is required")
	}

	id, err := spiffeid.FromString(c.spiffeID)
	if err != nil {
		return err
	}

	agentClient := serverClient.NewAgentClient()
	banResponse, err := agentClient.BanAgent(ctx, &agentv1.BanAgentRequest{
		Id: api.ProtoFromID(id),
	})
	if err != nil {
		return err
	}

	return c.printer.PrintProto(banResponse)
}

func (c *banCommand) AppendFlags(fs *flag.FlagSet) {
	fs.StringVar(&c.spiffeID, "spiffeID", "", "The SPIFFE ID of the agent to ban (agent identity)")
	cliprinter.AppendFlagWithCustomPretty(&c.printer, fs, c.env, prettyPrintBanResult)
}

func prettyPrintBanResult(env *commoncli.Env, _ ...any) error {
	env.Println("Agent banned successfully")
	return nil
}
